#' Remove the quoted parts of a string.
#'
#' See [strex::str_remove_quoted()].
#'
#' @inheritParams strex::str_remove_quoted
#'
#' @export
remove_quoted <- strex::str_remove_quoted

#' @rdname remove_quoted
#' @export
str_remove_quoted <- remove_quoted
